import numpy as np
from matplotlib import pyplot as plt
import pandas as pd
import scipy.interpolate as interpolate
from scipy.signal import filtfilt, butter, detrend, savgol_filter
import pywt
from sklearn import preprocessing
import scipy
import data_processing_functions as dpf
import datetime
import seaborn as sns
import statistics

#Forsøk på et en objektorientert metode

#Objekt som tar inn tidspunkter, trykk, ppg, vekt, vekt_ppg, hc_systolic, time, butter_level
#Computes filtered_pressure
class Measurement:

    T1TimeArduino = None
    CPTimeArduino = None
    T3TimeArduino = None
    T1TimeChart = None
    CPTimeChart = None
    T3TimeChart = None
    pressFilt = None
    timeLabChart = None
    fs_LabChart = None
    HCSystolic = None
    averagedDiastolic = None
    fingerPressureHC = None

    def __init__(self, timeStampT1, timeStampCP, timeStampT3, dataArduinoPath, ChartDataAddress, nameListArduino, nameListChart):
        #Initializes the class. Also reads arduino data
        sns.set()
        SMALL_SIZE = 24
        MEDIUM_SIZE = 10
        BIGGER_SIZE = 24

        plt.rc('font', size=SMALL_SIZE)  # controls default text sizes
        plt.rc('axes', titlesize=SMALL_SIZE)  # fontsize of the axes title
        plt.rc('axes', labelsize=MEDIUM_SIZE)  # fontsize of the x and y labels
        plt.rc('xtick', labelsize=12)  # fontsize of the tick labels
        plt.rc('ytick', labelsize=12)  # fontsize of the tick labels
        plt.rc('legend', fontsize=SMALL_SIZE)  # legend fontsize
        plt.rc('figure', titlesize=BIGGER_SIZE)  # fontsize of the figure title
        #plt.rc('axes', facecolor='beige')


        dataArduino = pd.read_csv(dataArduinoPath, sep=",", names=nameListArduino, skiprows=1)
        self.arduinoNameList = nameListArduino
        self.chartNameList = nameListChart

        timeArduino = (dataArduino.Time.to_numpy() / 1000)  # divide by 1000 to get seconds
        timeArduino = timeArduino - timeArduino[0]
        self.timeArduino = timeArduino + dataArduino["timestamp"][0]

        self.Pressure0 = dataArduino.Pressure0.to_numpy() #Right foot furthest back
        self.Pressure1 = dataArduino.Pressure1.to_numpy() #Right foot second furthest back
        self.Pressure2 = dataArduino.Pressure2.to_numpy() #Right foot forward to the right
        self.Pressure3 = dataArduino.Pressure3.to_numpy() #Right foot middle
        self.Pressure4 = dataArduino.Pressure4.to_numpy() #Left foot forward right
        self.Pressure5 = dataArduino.Pressure5.to_numpy() #Right foot forward left
        self.Pressure6 = dataArduino.Pressure6.to_numpy() #Left foot middle
        self.Pressure7 = dataArduino.Pressure7.to_numpy() #Left foot forward left
        self.Pressure8 = dataArduino.Pressure8.to_numpy() #Left foot second furthest back
        self.Pressure9 = dataArduino.Pressure9.to_numpy() #Left foot furthest back

        self.PPG = dataArduino.PPG.to_numpy()
        self.Scale = dataArduino.Scale.to_numpy()
        self.PPG2 = self.PPG*self.PPG

        self.fs_Arduino = (self.timeArduino[-1] - self.timeArduino[0]) / len(self.timeArduino)
        self.hz_Arduino = 1 / self.fs_Arduino
        self.timeArduinoScale = self.timeArduino[1::2]
        #self.Scale = self.Scale[1::2] #Decided to handle this later so i can reuse segmentation code
        self.PPGScale = self.PPG[1::2]
        self.fs_Scale = (self.timeArduinoScale[-1] - self.timeArduinoScale[0]) / len(self.timeArduinoScale) #Que?
        self.dataArduinoPath = dataArduinoPath
        self.chartAddress = ChartDataAddress
        self.T1TimeString = timeStampT1
        self.CPTimeString = timeStampCP
        self.T3TimeString = timeStampT3

        self.pressSegT1 = None
        self.normPressSegT1 = None
        self.avgPressSegT1 = None
        self.pressSegCP = None
        self.normPressSegCP = None
        self.avgPressSegCP = None
        self.pressSegT3 = None
        self.normPressSegT3 = None
        self.avgPressSegT3 = None

        self.PPGSegT1 = None
        self.normPPGSegT1 = None
        self.avgPPGSegT1 = None
        self.PPGSegCP = None
        self.normPPGSegCP = None
        self.avgPPGSegCP = None
        self.PPGSegT3 = None
        self.normPPGSegT3 = None
        self.avgPPGSegT3 = None

        #computing ddPPG
        #Just testing what filtering the ppg will do - no good is the conclusion
        #sos = butter(N=12 , Wn=[1,10], btype='bandpass', fs=self.hz_Arduino, output='sos')
        #self.PPG = scipy.signal.sosfilt(sos, self.PPG)

        polyOrder = 3
        windowSizeSeconds = 0.15 #Change this back to 0.15
        windowSizeArduino = int(windowSizeSeconds / self.fs_Arduino)
        if windowSizeArduino % 2 == 0:
            windowSizeArduino = windowSizeArduino + 1
        self.PPGFilt = savgol_filter(self.PPG, windowSizeArduino, polyOrder)
        self.dPPGFilt = savgol_filter(self.PPG, windowSizeArduino, polyOrder, deriv=1)
        self.ddPPGFilt = savgol_filter(self.PPG, windowSizeArduino, polyOrder, deriv=2)
        #dppg = np.gradient(self.PPGFilt)
        #polyOrder = 3
        #windowSizeSeconds = 0.15 #Change this back to 0.15
        #windowSizeArduino = int(windowSizeSeconds / self.fs_Arduino)
        #if windowSizeArduino % 2 == 0:
        #    windowSizeArduino = windowSizeArduino + 1
        #self.dPPGFilt = savgol_filter(dppg, windowSizeArduino, polyOrder)
        #ddppg = np.gradient(self.dPPGFilt)

        # Filtering double derivative to identify peaks
        #polyOrder = 3
        #windowSizeSeconds = 0.15 #Change this back to 0.15
        #windowSizeArduino = int(windowSizeSeconds / self.fs_Arduino)
        #if windowSizeArduino % 2 == 0:
        #    windowSizeArduino = windowSizeArduino + 1
        #self.ddPPGFilt = savgol_filter(ddppg, windowSizeArduino, polyOrder)

        # Need the derivative for the scale measurement as well
        polyOrder = 3
        windowSizeSeconds = 0.15
        windowSizeScale = int(windowSizeSeconds / self.fs_Scale)
        if windowSizeScale % 2 == 0:
            windowSizeScale = windowSizeScale + 1
        self.PPGFiltScale = savgol_filter(self.PPGScale, windowSizeScale, polyOrder)
        dppgScale = np.gradient(self.PPGFiltScale)

        polyOrder = 3
        windowSizeSeconds = 0.15
        windowSizeScale = int(windowSizeSeconds / self.fs_Scale)
        if windowSizeScale % 2 == 0:
            windowSizeScale = windowSizeScale + 1
        self.dPPGFiltScale = savgol_filter(dppgScale, windowSizeScale, polyOrder)
        ddppgScale = np.gradient(self.dPPGFiltScale)

        polyOrder = 3
        windowSizeSeconds = 0.15
        windowSizeScale = int(windowSizeSeconds / self.fs_Scale)
        if windowSizeScale % 2 == 0:
            windowSizeScale = windowSizeScale + 1
        self.ddPPGFiltScale = savgol_filter(ddppgScale, windowSizeScale, polyOrder)

    def filterPressure(self, butterLevel, passBand):
        sos = butter(N=butterLevel, Wn=passBand, btype='bandpass', fs=self.hz_Arduino, output='sos')
        self.pressFilt0 = scipy.signal.sosfiltfilt(sos, self.Pressure0)
        self.pressFilt1 = scipy.signal.sosfiltfilt(sos, self.Pressure1)
        self.pressFilt2 = scipy.signal.sosfiltfilt(sos, self.Pressure2)
        self.pressFilt3 = scipy.signal.sosfiltfilt(sos, self.Pressure3)
        self.pressFilt4 = scipy.signal.sosfiltfilt(sos, self.Pressure4)
        self.pressFilt5 = scipy.signal.sosfiltfilt(sos, self.Pressure5)
        self.pressFilt6 = scipy.signal.sosfiltfilt(sos, self.Pressure6)
        self.pressFilt7 = scipy.signal.sosfiltfilt(sos, self.Pressure7)
        self.pressFilt8 = scipy.signal.sosfiltfilt(sos, self.Pressure8)
        self.pressFilt9 = scipy.signal.sosfiltfilt(sos, self.Pressure9)



    def loadChartData(self):
        #reads the labchartdata and extracts the interesting data into a readable format
        data = pd.read_csv(self.chartAddress, sep="\t", names=self.chartNameList, header=None)
        startLocations = data.loc[data["Time"] == "Range="]
        indexFinalStart = startLocations.index[-1]
        #data.iloc[indexFinalStart - 5]
        startTimeString = data["Finger_Pressure"][indexFinalStart - 4]
        startTimeList = startTimeString.split()[0].split(".") + startTimeString.split()[1].split(":")
        startTimeList = startTimeList[:-1] + startTimeList[-1].split(",")
        for i in range(len(startTimeList)):
            startTimeList[i] = int(startTimeList[i])
        epochLabChart = datetime.datetime(startTimeList[2], startTimeList[1], startTimeList[0], startTimeList[3],
                                          minute=startTimeList[4], second=startTimeList[5],
                                          microsecond=startTimeList[6] * 1000).timestamp()
        data.drop(list(range(indexFinalStart + 1)), inplace=True)
        numpyArrayList = []
        interestingDataList = ["Time", "HC_Systolic", "Active_Cuff", "Finger_Pressure_HC"]
        for i in interestingDataList:
            data[i] = data[i].str.replace(',', '.')
            data[i] = data[i].astype(float)
            data[i] = data[i].fillna(0)
            numpyArrayList.append(data[i].to_numpy())
        timeLabChart = numpyArrayList[0]
        self.timeLabChart = timeLabChart + epochLabChart
        self.fs_LabChart = (self.timeLabChart[-1] - self.timeLabChart[0]) / len(self.timeLabChart)
        self.HCSystolic = numpyArrayList[1]
        self.averagedDiastolic = numpyArrayList[2]
        self.fingerPressureHC = numpyArrayList[3]

    def findMatchingTime(self, timeArray, timeStamp):
        #Should probably be a private function
        for i in range(len(timeArray)):
            if abs(timeArray[i] - timeStamp) < 0.01:
                return i

    def computeTimeIndice(self, timeSet, timeArray):
        # Timeset should be a list [start, stop] where start and stop should be written as dd:mm:yy:hh:mm:ss:ms
        epochTimeSet = []
        for i in timeSet:
            timeList = i.split(":")
            for i in range(len(timeList)):
                timeList[i] = int(timeList[i])
            epochTimeStamp = datetime.datetime(timeList[2], timeList[1], timeList[0], timeList[3],
                                               minute=timeList[4], second=timeList[5],
                                               microsecond=timeList[6] * 1000).timestamp()
            epochTimeSet.append(self.findMatchingTime(timeArray, epochTimeStamp))
        timeIndice = epochTimeSet
        return timeIndice
        #convert string time stamps into epoch time stamps

    def SetTimeIndices(self):
        timeIndice = self.computeTimeIndice(self.T1TimeString, self.timeArduino)
        self.T1TimeArduino = timeIndice
        timeIndice = self.computeTimeIndice(self.CPTimeString, self.timeArduino)
        self.CPTimeArduino = timeIndice
        timeIndice = self.computeTimeIndice(self.T3TimeString, self.timeArduino)
        self.T3TimeArduino = timeIndice
        timeIndice = self.computeTimeIndice(self.T1TimeString, self.timeLabChart)
        self.T1TimeChart = timeIndice
        timeIndice = self.computeTimeIndice(self.CPTimeString, self.timeLabChart)
        self.CPTimeChart = timeIndice
        timeIndice = self.computeTimeIndice(self.T3TimeString, self.timeLabChart)
        self.T3TimeChart = timeIndice

    def averageFingerPressure(self):
        #Computes an average finger pressure by using savitzky golay filter
        polyOrder = 3
        windowSizeSeconds = 35
        windowSize = int(windowSizeSeconds / self.fs_LabChart)
        if windowSize % 2 == 0:
            windowSize = windowSize + 1
        self.HCSystolicFiltered = savgol_filter(self.HCSystolic, windowSize, polyOrder)

    def plotAvgFingPress(self):
        #Plot the averaged finger pressure
        timeIndexesLabchart = self.T1TimeChart + self.CPTimeChart + self.T3TimeChart
        plt.figure(figsize=(32, 16), dpi=150)
        plt.ylim(70, 180)
        # plt.plot(HC_Systolic[0:-1])
        # plt.plot(timeLabChart[0:-1], HC_Systolic[0:-1])
        plt.plot(self.timeLabChart[0:-1], self.HCSystolicFiltered[0:-1])
        for i in timeIndexesLabchart:
            plt.axvline(x=self.timeLabChart[i])
        plt.show()

    def findPPGPeaks(self, threshold, timeBetween):
        #Finds the peaks of the ppg for segmentation
        #Another idea is to find the PPG squared peaks. Should be easier (maybe)
        samplesBetweenEach = timeBetween/self.fs_Arduino
        self.peaksPPG, properties = scipy.signal.find_peaks(self.PPGFilt, height=threshold, distance=samplesBetweenEach)
        self.peaksPPG2, properties = scipy.signal.find_peaks(self.PPG2, height=threshold, distance=samplesBetweenEach)
        samplesBetweenEach = timeBetween/self.fs_Scale
        self.peaksPPGScale, properties = scipy.signal.find_peaks(self.PPGFiltScale, height=threshold, distance=samplesBetweenEach)


    def findddPPGPeaks(self, threshold, timeBetween):
        #Finds the peaks of the ddPPG for segmentation
        samplesBetweenEach = timeBetween/self.fs_Arduino
        self.peaksddPPG, properties = scipy.signal.find_peaks(self.ddPPGFilt, height=threshold, distance=samplesBetweenEach)
        samplesBetweenEach = timeBetween/self.fs_Scale
        self.peaksddPPGScale, properties = scipy.signal.find_peaks(self.ddPPGFiltScale, height=threshold, distance=samplesBetweenEach)

    def organizePeaks(self):
        #I think it is better to do the sanity check here on the peaks.
        #Compute median distance between peaks, then i look through the gaps between the peaks. If a gap is too long one of the peaks is wrong.
        #But which one?
        #gapLengths = np.zeros(len(self.peaksPPG) - 1)
        #for i in range(len(self.peaksPPG)):
        #    gapLengths[i] = self.peaksPPG[i + 1] - self.peaksPPG[i]
        #medianLength = gapLengths[int(len(gapLengths)/2)]
        #wrongGapIndex = []
        #for i in range(len(gapLengths)):
        #    if abs(medianLength - gapLengths[i]) > 0.05*medianLength:
        #        #Something is wrong and i should remove one of the peaks. But im not sure which one.
        #        wrongGapIndex.append(i)
        #Checking which indices are possibly wrong. Whats interesting to check is wether

        T1Peaks = []
        T3Peaks = []
        CPPeaks = []

        for i in self.peaksPPG:
            if i > self.T1TimeArduino[0] and i < self.T1TimeArduino[1]:
                T1Peaks.append(i)
            elif i > self.CPTimeArduino[0] and i < self.CPTimeArduino[1]:
                CPPeaks.append(i)
            elif i > self.T3TimeArduino[0] and i < self.T3TimeArduino[1]:
                T3Peaks.append(i)

        self.T1Peaks = T1Peaks
        self.CPPeaks = CPPeaks
        self.T3Peaks = T3Peaks

        T1Peaks2 = []
        T3Peaks2 = []
        CPPeaks2 = []

        for i in self.peaksPPG2:
            if i > self.T1TimeArduino[0] and i < self.T1TimeArduino[1]:
                T1Peaks2.append(i)
            elif i > self.CPTimeArduino[0] and i < self.CPTimeArduino[1]:
                CPPeaks2.append(i)
            elif i > self.T3TimeArduino[0] and i < self.T3TimeArduino[1]:
                T3Peaks2.append(i)

        self.T1Peaks2 = T1Peaks2
        self.CPPeaks2 = CPPeaks2
        self.T3Peaks2 = T3Peaks2


    def sanityCheckSeg(self, segmentList):
        minLength = 100000
        # Identifying the shortest period and making all the segments that length by cutting off the end
        # Should add some sanity check to remove wrongly identified segments. For instance by length
        avgLength = 0
        lengthList = []
        for i in range(len(segmentList)):
            lengthList.append(len(segmentList[i]))
        #median = lengthList[int(len(lengthList)/2)]
        median = statistics.median(lengthList)

        for j in range(len(segmentList)):
        #    avgLength = avgLength + len(segmentList[j])
            if minLength > len(segmentList[j]):
                minLength = len(segmentList[j])
        avgLength = avgLength / len(segmentList)
        avgLength = avgLength + 0.1 * avgLength  # Not in use atm
        popList = []
        for k in range(len(segmentList)):
            if abs(len(segmentList[k]) - median) > 0.05*median:
                # pressureSegmentList.pop(k)
                popList.append(k) #List of the indices im gonna pop (remove)
            else:
                segmentList[k] = segmentList[k][0:minLength] #Setting all segments to the same length for easier plotting
        for l in range(len(popList)):
            segmentList.pop(popList[l] - l)
        #print(popList)
        return segmentList, popList

    def segmentUsingPPGT1(self, peaks, fs, press=False, PPG=False):
        #Segments the data by using the identified PPG peaks
        #How do i choose which peaks i want to use?
        #Should change this to just use self.peaksT1. Doesnt need me to give it peaks
        if press:
            pressureSegmentList0 = []
            pressureSegmentList1 = []
            pressureSegmentList2 = []
            pressureSegmentList3 = []
            pressureSegmentList4 = []
            pressureSegmentList5 = []
            pressureSegmentList6 = []
            pressureSegmentList7 = []
            pressureSegmentList8 = []
            pressureSegmentList9 = []
            for i in range(len(peaks) - 1):
                # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
                segment0 = self.pressFilt0[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment1 = self.pressFilt1[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment2 = self.pressFilt2[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment3 = self.pressFilt3[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment4 = self.pressFilt4[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment5 = self.pressFilt5[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment6 = self.pressFilt6[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment7 = self.pressFilt7[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment8 = self.pressFilt8[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment9 = self.pressFilt9[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]

                pressureSegmentList0.append(segment0)
                pressureSegmentList1.append(segment1)
                pressureSegmentList2.append(segment2)
                pressureSegmentList3.append(segment3)
                pressureSegmentList4.append(segment4)
                pressureSegmentList5.append(segment5)
                pressureSegmentList6.append(segment6)
                pressureSegmentList7.append(segment7)
                pressureSegmentList8.append(segment8)
                pressureSegmentList9.append(segment9)

                #Doing sanity checks

            self.pressureSegmentList0T1, popList = self.sanityCheckSeg(pressureSegmentList0)
            self.pressureSegmentList1T1, popList = self.sanityCheckSeg(pressureSegmentList1)
            self.pressureSegmentList2T1, popList = self.sanityCheckSeg(pressureSegmentList2)
            self.pressureSegmentList3T1, popList = self.sanityCheckSeg(pressureSegmentList3)
            self.pressureSegmentList4T1, popList = self.sanityCheckSeg(pressureSegmentList4)
            self.pressureSegmentList5T1, popList = self.sanityCheckSeg(pressureSegmentList5)
            self.pressureSegmentList6T1, popList = self.sanityCheckSeg(pressureSegmentList6)
            self.pressureSegmentList7T1, popList = self.sanityCheckSeg(pressureSegmentList7)
            self.pressureSegmentList8T1, popList = self.sanityCheckSeg(pressureSegmentList8)
            self.pressureSegmentList9T1, popList = self.sanityCheckSeg(pressureSegmentList9)
            self.popListT1 = popList
            #print("PopListT1: ", self.popListT1)
        elif PPG:
            PPGSegmentList = []
            for i in range(len(peaks) - 1):
                # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
                segment = self.PPGFilt[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                PPGSegmentList.append(segment)
            PPGSegmentList, popList = self.sanityCheckSeg(PPGSegmentList)
            self.PPGSegmentListT1 = PPGSegmentList
            self.popListT1 = popList
            #print("PopListT1: ", self.popListT1)

    def segmentUsingPPGCP(self, peaks, fs, press=False, PPG=False):
        #Segments the data by using the identified PPG peaks
        #How do i choose which peaks i want to use?

        if press:
            pressureSegmentList0 = []
            pressureSegmentList1 = []
            pressureSegmentList2 = []
            pressureSegmentList3 = []
            pressureSegmentList4 = []
            pressureSegmentList5 = []
            pressureSegmentList6 = []
            pressureSegmentList7 = []
            pressureSegmentList8 = []
            pressureSegmentList9 = []
            for i in range(len(peaks) - 1):
                # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
                segment0 = self.pressFilt0[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment1 = self.pressFilt1[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment2 = self.pressFilt2[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment3 = self.pressFilt3[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment4 = self.pressFilt4[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment5 = self.pressFilt5[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment6 = self.pressFilt6[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment7 = self.pressFilt7[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment8 = self.pressFilt8[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment9 = self.pressFilt9[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]

                pressureSegmentList0.append(segment0)
                pressureSegmentList1.append(segment1)
                pressureSegmentList2.append(segment2)
                pressureSegmentList3.append(segment3)
                pressureSegmentList4.append(segment4)
                pressureSegmentList5.append(segment5)
                pressureSegmentList6.append(segment6)
                pressureSegmentList7.append(segment7)
                pressureSegmentList8.append(segment8)
                pressureSegmentList9.append(segment9)

                #Doing sanity checks
            self.pressureSegmentList0CP, popList = self.sanityCheckSeg(pressureSegmentList0)
            self.pressureSegmentList1CP, popList = self.sanityCheckSeg(pressureSegmentList1)
            self.pressureSegmentList2CP, popList = self.sanityCheckSeg(pressureSegmentList2)
            self.pressureSegmentList3CP, popList = self.sanityCheckSeg(pressureSegmentList3)
            self.pressureSegmentList4CP, popList = self.sanityCheckSeg(pressureSegmentList4)
            self.pressureSegmentList5CP, popList = self.sanityCheckSeg(pressureSegmentList5)
            self.pressureSegmentList6CP, popList = self.sanityCheckSeg(pressureSegmentList6)
            self.pressureSegmentList7CP, popList = self.sanityCheckSeg(pressureSegmentList7)
            self.pressureSegmentList8CP, popList = self.sanityCheckSeg(pressureSegmentList8)
            self.pressureSegmentList9CP, popList = self.sanityCheckSeg(pressureSegmentList9)
            self.popListCP = popList
        elif PPG:
            PPGSegmentList = []
            for i in range(len(peaks) - 1):
                # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
                segment = self.PPGFilt[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(
                0.5 / fs)]
                PPGSegmentList.append(segment)
            PPGSegmentList, popList = self.sanityCheckSeg(PPGSegmentList)
            self.PPGSegmentListCP = PPGSegmentList
            self.popListCP = popList
    def segmentUsingPPGT3(self, peaks, fs, press=False, PPG=False):
        #Segments the data by using the identified PPG peaks
        #How do i choose which peaks i want to use?

        if press:
            pressureSegmentList0 = []
            pressureSegmentList1 = []
            pressureSegmentList2 = []
            pressureSegmentList3 = []
            pressureSegmentList4 = []
            pressureSegmentList5 = []
            pressureSegmentList6 = []
            pressureSegmentList7 = []
            pressureSegmentList8 = []
            pressureSegmentList9 = []
            for i in range(len(peaks) - 1):
                # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
                segment0 = self.pressFilt0[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment1 = self.pressFilt1[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment2 = self.pressFilt2[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment3 = self.pressFilt3[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment4 = self.pressFilt4[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment5 = self.pressFilt5[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment6 = self.pressFilt6[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment7 = self.pressFilt7[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment8 = self.pressFilt8[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]
                segment9 = self.pressFilt9[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(0.5 / fs)]

                pressureSegmentList0.append(segment0)
                pressureSegmentList1.append(segment1)
                pressureSegmentList2.append(segment2)
                pressureSegmentList3.append(segment3)
                pressureSegmentList4.append(segment4)
                pressureSegmentList5.append(segment5)
                pressureSegmentList6.append(segment6)
                pressureSegmentList7.append(segment7)
                pressureSegmentList8.append(segment8)
                pressureSegmentList9.append(segment9)

                #Doing sanity checks
            self.pressureSegmentList0T3, popList = self.sanityCheckSeg(pressureSegmentList0)
            self.pressureSegmentList1T3, popList = self.sanityCheckSeg(pressureSegmentList1)
            self.pressureSegmentList2T3, popList = self.sanityCheckSeg(pressureSegmentList2)
            self.pressureSegmentList3T3, popList = self.sanityCheckSeg(pressureSegmentList3)
            self.pressureSegmentList4T3, popList = self.sanityCheckSeg(pressureSegmentList4)
            self.pressureSegmentList5T3, popList = self.sanityCheckSeg(pressureSegmentList5)
            self.pressureSegmentList6T3, popList = self.sanityCheckSeg(pressureSegmentList6)
            self.pressureSegmentList7T3, popList = self.sanityCheckSeg(pressureSegmentList7)
            self.pressureSegmentList8T3, popList = self.sanityCheckSeg(pressureSegmentList8)
            self.pressureSegmentList9T3, popList = self.sanityCheckSeg(pressureSegmentList9)
            self.popListT3 = popList

        elif PPG:
            PPGSegmentList = []
            for i in range(len(peaks) - 1):
                # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
                segment = self.PPGFilt[peaks[i] - int(0.5 / fs): peaks[i + 1] + int(
                0.5 / fs)]  # This will probably make wrongly segmented segments worse.
                PPGSegmentList.append(segment)
            PPGSegmentList, popList = self.sanityCheckSeg(PPGSegmentList)
            self.PPGSegmentListT3 = PPGSegmentList
            self.popListT3 = popList

    def normAndAvgPressSegT1(self):
        #Shit - This does not consider T1, CP and T3 - Start here next time (22.05.2022) and then fix plotting.
        normSeg0 = []
        for i in self.pressureSegmentList0T1:
            normSeg0.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg0T1 = normSeg0
        self.avgSeg0T1 = dpf.averageSegments(segments=normSeg0)

        normSeg1 = []
        for i in self.pressureSegmentList1T1:
            normSeg1.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg1T1 = normSeg1
        self.avgSeg1T1 = dpf.averageSegments(segments=normSeg1)

        normSeg2 = []
        for i in self.pressureSegmentList2T1:
            normSeg2.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg2T1 = normSeg2
        self.avgSeg2T1 = dpf.averageSegments(segments=normSeg2)

        normSeg3 = []
        for i in self.pressureSegmentList3T1:
            normSeg3.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg3T1 = normSeg3
        self.avgSeg3T1 = dpf.averageSegments(segments=normSeg3)

        normSeg4 = []
        for i in self.pressureSegmentList4T1:
            normSeg4.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg4T1 = normSeg4
        self.avgSeg4T1 = dpf.averageSegments(segments=normSeg4)

        normSeg5 = []
        for i in self.pressureSegmentList5T1:
            normSeg5.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg5T1 = normSeg5
        self.avgSeg5T1 = dpf.averageSegments(segments=normSeg5)

        normSeg6 = []
        for i in self.pressureSegmentList6T1:
            normSeg6.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg6T1 = normSeg6
        self.avgSeg6T1 = dpf.averageSegments(segments=normSeg6)

        normSeg7 = []
        for i in self.pressureSegmentList7T1:
            normSeg7.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg7T1 = normSeg7
        self.avgSeg7T1 = dpf.averageSegments(segments=normSeg7)

        normSeg8 = []
        for i in self.pressureSegmentList8T1:
            normSeg8.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg8T1 = normSeg8
        self.avgSeg8T1 = dpf.averageSegments(segments=normSeg8)

        normSeg9 = []
        for i in self.pressureSegmentList9T1:
            normSeg9.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg9T1 = normSeg9
        self.avgSeg9T1 = dpf.averageSegments(segments=normSeg9)

    def normAndAvgPressSegCP(self):
        #Shit - This does not consider T1, CP and T3 - Start here next time (22.05.2022) and then fix plotting.
        normSeg0 = []
        for i in self.pressureSegmentList0CP:
            normSeg0.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg0CP = normSeg0
        self.avgSeg0CP = dpf.averageSegments(segments=normSeg0)

        normSeg1 = []
        for i in self.pressureSegmentList1CP:
            normSeg1.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg1CP = normSeg1
        self.avgSeg1CP = dpf.averageSegments(segments=normSeg1)

        normSeg2 = []
        for i in self.pressureSegmentList2CP:
            normSeg2.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg2CP = normSeg2
        self.avgSeg2CP = dpf.averageSegments(segments=normSeg2)

        normSeg3 = []
        for i in self.pressureSegmentList3CP:
            normSeg3.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg3CP = normSeg3
        self.avgSeg3CP = dpf.averageSegments(segments=normSeg3)

        normSeg4 = []
        for i in self.pressureSegmentList4CP:
            normSeg4.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg4CP = normSeg4
        self.avgSeg4CP = dpf.averageSegments(segments=normSeg4)

        normSeg5 = []
        for i in self.pressureSegmentList5CP:
            normSeg5.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg5CP = normSeg5
        self.avgSeg5CP = dpf.averageSegments(segments=normSeg5)

        normSeg6 = []
        for i in self.pressureSegmentList6CP:
            normSeg6.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg6CP = normSeg6
        self.avgSeg6CP = dpf.averageSegments(segments=normSeg6)

        normSeg7 = []
        for i in self.pressureSegmentList7CP:
            normSeg7.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg7CP = normSeg7
        self.avgSeg7CP = dpf.averageSegments(segments=normSeg7)

        normSeg8 = []
        for i in self.pressureSegmentList8CP:
            normSeg8.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg8CP = normSeg8
        self.avgSeg8CP = dpf.averageSegments(segments=normSeg8)

        normSeg9 = []
        for i in self.pressureSegmentList9CP:
            normSeg9.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg9CP = normSeg9
        self.avgSeg9CP = dpf.averageSegments(segments=normSeg9)

    def normAndAvgPressSegT3(self):
        #Shit - This does not consider T1, CP and T3 - Start here next time (22.05.2022) and then fix plotting.
        normSeg0 = []
        for i in self.pressureSegmentList0T3:
            normSeg0.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg0T3 = normSeg0
        self.avgSeg0T3 = dpf.averageSegments(segments=normSeg0)

        normSeg1 = []
        for i in self.pressureSegmentList1T3:
            normSeg1.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg1T3 = normSeg1
        self.avgSeg1T3 = dpf.averageSegments(segments=normSeg1)

        normSeg2 = []
        for i in self.pressureSegmentList2T3:
            normSeg2.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg2T3 = normSeg2
        self.avgSeg2T3 = dpf.averageSegments(segments=normSeg2)

        normSeg3 = []
        for i in self.pressureSegmentList3T3:
            normSeg3.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg3T3 = normSeg3
        self.avgSeg3T3 = dpf.averageSegments(segments=normSeg3)

        normSeg4 = []
        for i in self.pressureSegmentList4T3:
            normSeg4.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg4T3 = normSeg4
        self.avgSeg4T3 = dpf.averageSegments(segments=normSeg4)

        normSeg5 = []
        for i in self.pressureSegmentList5T3:
            normSeg5.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg5T3 = normSeg5
        self.avgSeg5T3 = dpf.averageSegments(segments=normSeg5)

        normSeg6 = []
        for i in self.pressureSegmentList6T3:
            normSeg6.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg6T3 = normSeg6
        self.avgSeg6T3 = dpf.averageSegments(segments=normSeg6)

        normSeg7 = []
        for i in self.pressureSegmentList7T3:
            normSeg7.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg7T3 = normSeg7
        self.avgSeg7T3 = dpf.averageSegments(segments=normSeg7)

        normSeg8 = []
        for i in self.pressureSegmentList8T3:
            normSeg8.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg8T3 = normSeg8
        self.avgSeg8T3 = dpf.averageSegments(segments=normSeg8)

        normSeg9 = []
        for i in self.pressureSegmentList9T3:
            normSeg9.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSeg9T3 = normSeg9
        self.avgSeg9T3 = dpf.averageSegments(segments=normSeg9)

    def normAndAvgPPGSegT1(self):
        normSeg = []
        for i in self.PPGSegmentListT1:
            normSeg.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSegPPGT1 = normSeg
        self.avgSegPPGT1 = dpf.averageSegments(segments=normSeg)

    def normAndAvgPPGSegCP(self):
        normSeg = []
        for i in self.PPGSegmentListCP:
            normSeg.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSegPPGCP = normSeg
        self.avgSegPPGCP = dpf.averageSegments(segments=normSeg)

    def normAndAvgPPGSegT3(self):
        normSeg = []
        for i in self.PPGSegmentListT3:
            normSeg.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.normSegPPGT3 = normSeg
        self.avgSegPPGT3 = dpf.averageSegments(segments=normSeg)

    def segmentNormalizeAndAverage(self, fs, segPress, segPPG, PPG2 = False, ddPPG = False, segScale = False, T1=False, CP=False, T3=False):
        #ref is the reference we use to segments. Called peaks later
        #ddPPG is not fixed

        if T1:
            if ddPPG:
                ref = self.ddPPGFilt[self.T1TimeArduino[0]:self.T1TimeArduino[1]]
            elif PPG2:
                ref = self.T1Peaks2
            else:
                #ref = self.PPG[self.T1TimeArduino[0]:self.T1TimeArduino[1]]
                ref = self.T1Peaks
            self.segmentUsingPPGT1(ref, fs, press=segPress, PPG=segPPG)
            if segPress:
                self.normAndAvgPressSegT1()
            elif segPPG:
                self.normAndAvgPPGSegT1()

        elif CP:
            if ddPPG:
                ref = self.ddPPGFilt[self.CPTimeArduino[0]:self.CPTimeArduino[1]]
            elif PPG2:
                ref = self.CPPeaks2
            else:
                #ref = self.PPG[self.CPTimeArduino[0]:self.CPTimeArduino[1]]
                ref = self.CPPeaks
            self.segmentUsingPPGCP(ref, fs, press=segPress, PPG=segPPG)
            if segPress:
                self.normAndAvgPressSegCP()
            if segPPG:
                self.normAndAvgPPGSegCP()
        elif T3:
            if ddPPG:
                ref = self.ddPPGFilt[self.T3TimeArduino[0]:self.T3TimeArduino[1]]
            elif PPG2:
                ref = self.T1Peaks2
            else:
                #ref = self.PPG[self.T3TimeArduino[0]:self.T3TimeArduino[1]]
                ref = self.T3Peaks
            self.segmentUsingPPGT3(ref, fs, press=segPress, PPG=segPPG)
            if segPress:
                self.normAndAvgPressSegT3()
            if segPPG:
                self.normAndAvgPPGSegT3()


    def segmentPressure(self, ddPPG = False, PPG2 = False): #Should change the name of the variable for wether im segmenting ppg
        self.segmentNormalizeAndAverage(self.fs_Arduino, segPress=True, segPPG=False, PPG2=PPG2, ddPPG = ddPPG, T1=True)
        self.segmentNormalizeAndAverage(self.fs_Arduino, segPress=True, segPPG=False, PPG2=PPG2, ddPPG=ddPPG, CP=True)
        self.segmentNormalizeAndAverage(self.fs_Arduino, segPress=True, segPPG=False, PPG2=PPG2, ddPPG=ddPPG, T3=True)

    def segmentScalePressure(self, threshold, timeBetween): #Needs to be updated
        self.segmentNormalizeAndAverage(self.Scale, self.fs_Scale, threshold, timeBetween, T1 = True)
        self.segmentNormalizeAndAverage(self.Scale, self.fs_Scale, threshold, timeBetween, CP = True)
        self.segmentNormalizeAndAverage(self.Scale, self.fs_Scale, threshold, timeBetween, T3 = True)

    def segmentPPG(self, ddPPG = False, PPG2 = False):
        self.segmentNormalizeAndAverage(self.fs_Arduino, segPress=False, segPPG=True, PPG2=PPG2, ddPPG=ddPPG, T1=True)
        self.segmentNormalizeAndAverage(self.fs_Arduino, segPress=False, segPPG=True, PPG2=PPG2, ddPPG=ddPPG, CP=True)
        self.segmentNormalizeAndAverage(self.fs_Arduino, segPress=False, segPPG=True, PPG2=PPG2, ddPPG=ddPPG, T3=True)

    def plotSegPress(self, pressSelect, T1 = False, CP = False, T3 = False, savePlot = False, ID = ""):
        #Might be better to just make this 9 functions. One for each sensor
        if pressSelect == 0:
            if T1:
                avgData = self.avgSeg0T1
                normData = self.normSeg0T1
            elif CP:
                avgData = self.avgSeg0CP
                normData = self.normSeg0CP
            elif T3:
                avgData = self.avgSeg0T3
                normData = self.normSeg0T3
        elif pressSelect == 1:
            if T1:
                avgData = self.avgSeg1T1
                normData = self.normSeg1T1
            elif CP:
                avgData = self.avgSeg1CP
                normData = self.normSeg1CP
            elif T3:
                avgData = self.avgSeg1T3
                normData = self.normSeg1T3
        elif pressSelect == 2:
            if T1:
                avgData = self.avgSeg2T1
                normData = self.normSeg2T1
            elif CP:
                avgData = self.avgSeg2CP
                normData = self.normSeg2CP
            elif T3:
                avgData = self.avgSeg2T3
                normData = self.normSeg2T3
        elif pressSelect == 3:
            if T1:
                avgData = self.avgSeg3T1
                normData = self.normSeg3T1
            elif CP:
                avgData = self.avgSeg3CP
                normData = self.normSeg3CP
            elif T3:
                avgData = self.avgSeg3T3
                normData = self.normSeg3T3
        elif pressSelect == 4:
            if T1:
                avgData = self.avgSeg4T1
                normData = self.normSeg4T1
            elif CP:
                avgData = self.avgSeg4CP
                normData = self.normSeg4CP
            elif T3:
                avgData = self.avgSeg4T3
                normData = self.normSeg4T3
        elif pressSelect == 5:
            if T1:
                avgData = self.avgSeg5T1
                normData = self.avgSeg5T3
            elif CP:
                avgData = self.avgSeg5CP
                normData = self.normSeg5CP
            elif T3:
                avgData = self.avgSeg5T3
                normData = self.normSeg5T3
        elif pressSelect == 6:
            if T1:
                avgData = self.avgSeg6T1
                normData = self.normSeg6T1
            elif CP:
                avgData = self.avgSeg6CP
                normData = self.normSeg6CP
            elif T3:
                avgData = self.avgSeg6T3
                normData = self.normSeg6T3
        elif pressSelect == 7:
            if T1:
                avgData = self.avgSeg7T3
                normData = self.normSeg7T1
            elif CP:
                avgData = self.avgSeg7CP
                normData = self.normSeg7CP
            elif T3:
                avgData = self.avgSeg7T3
                normData = self.avgSeg2T3
        elif pressSelect == 8:
            if T1:
                avgData = self.avgSeg8T1
                normData = self.normSeg8T1
            elif CP:
                avgData = self.avgSeg8CP
                normData = self.normSeg8CP
            elif T3:
                avgData = self.avgSeg8T3
                normData = self.normSeg8T3
        elif pressSelect == 9:
            if T1:
                avgData = self.avgSeg9T1
                normData = self.normSeg9T1
            elif CP:
                avgData = self.avgSeg9CP
                normData = self.normSeg9CP
            elif T3:
                avgData = self.avgSeg9T3
                normData = self.normSeg9T3


        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(
            np.linspace(start=0, stop=((len(avgData)) * self.fs_Arduino), num=(len(avgData))),
            avgData[:], "r", linewidth=4)
        for i in range(len(normData)):
            plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
                                 num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.title("Pressure segmented and averaged")
        plt.xticks(np.arange(start=0, stop=((len(avgData)) * self.fs_Arduino), step=0.05))
        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\SegPress_" + ID
            plt.savefig(saveName)
        plt.show()

    def plotSegPressV2(self, pressSelect, T1=False, CP=False, T3=False, savePlot = False, ID = ""):
        # Might be better to just make this 9 functions. One for each sensor
        if pressSelect == 0:
            if T1:
                avgData = self.avgSeg0T1
                normData = self.normSeg0T1
            elif CP:
                avgData = self.avgSeg0CP
                normData = self.normSeg0CP
            elif T3:
                avgData = self.avgSeg0T3
                normData = self.normSeg0T3
        elif pressSelect == 1:
            if T1:
                avgData = self.avgSeg1T1
                normData = self.normSeg1T1
            elif CP:
                avgData = self.avgSeg1CP
                normData = self.normSeg1CP
            elif T3:
                avgData = self.avgSeg1T3
                normData = self.normSeg1T3
        elif pressSelect == 2:
            if T1:
                avgData = self.avgSeg2T1
                normData = self.normSeg2T1
            elif CP:
                avgData = self.avgSeg2CP
                normData = self.normSeg2CP
            elif T3:
                avgData = self.avgSeg2T3
                normData = self.normSeg2T3
        elif pressSelect == 3:
            if T1:
                avgData = self.avgSeg3T1
                normData = self.normSeg3T1
            elif CP:
                avgData = self.avgSeg3CP
                normData = self.normSeg3CP
            elif T3:
                avgData = self.avgSeg3T3
                normData = self.normSeg3T3
        elif pressSelect == 4:
            if T1:
                avgData = self.avgSeg4T1
                normData = self.normSeg4T1
            elif CP:
                avgData = self.avgSeg4CP
                normData = self.normSeg4CP
            elif T3:
                avgData = self.avgSeg4T3
                normData = self.normSeg4T3
        elif pressSelect == 5:
            if T1:
                avgData = self.avgSeg5T1
                normData = self.avgSeg5T3
            elif CP:
                avgData = self.avgSeg5CP
                normData = self.normSeg5CP
            elif T3:
                avgData = self.avgSeg5T3
                normData = self.normSeg5T3
        elif pressSelect == 6:
            if T1:
                avgData = self.avgSeg6T1
                normData = self.normSeg6T1
            elif CP:
                avgData = self.avgSeg6CP
                normData = self.normSeg6CP
            elif T3:
                avgData = self.avgSeg6T3
                normData = self.normSeg6T3
        elif pressSelect == 7:
            if T1:
                avgData = self.avgSeg7T3
                normData = self.normSeg7T1
            elif CP:
                avgData = self.avgSeg7CP
                normData = self.normSeg7CP
            elif T3:
                avgData = self.avgSeg7T3
                normData = self.avgSeg2T3
        elif pressSelect == 8:
            if T1:
                avgData = self.avgSeg8T1
                normData = self.normSeg8T1
            elif CP:
                avgData = self.avgSeg8CP
                normData = self.normSeg8CP
            elif T3:
                avgData = self.avgSeg8T3
                normData = self.normSeg8T3
        elif pressSelect == 9:
            if T1:
                avgData = self.avgSeg9T1
                normData = self.normSeg9T1
            elif CP:
                avgData = self.avgSeg9CP
                normData = self.normSeg9CP
            elif T3:
                avgData = self.avgSeg9T3
                normData = self.normSeg9T3
        fig, ax1 = plt.subplots(figsize=(32, 16), dpi = 150)
        ax1.plot(np.linspace(start=0, stop=((len(avgData)) * self.fs_Arduino), num=(len(avgData))),
                 avgData[:], "r", linewidth=4)
        #plt.plot(
        #    np.linspace(start=0, stop=((len(avgData)) * self.fs_Arduino), num=(len(avgData))),
        #    avgData[:], "r", linewidth=4)
        axisList = []
        for i in range(len(normData)):
            axisList.append(ax1.twinx())
            axisList[i].plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino, num=(len(normData[i]))),
                             normData[i], "b--")
            fig.axes[i].get_yaxis().set_visible(False)
            #plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
            #                     num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.title("Pressure segmented and averaged plotV2")
        plt.xticks(np.arange(start=0, stop=((len(avgData)) * self.fs_Arduino), step=0.05))
        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\SegPressV2_" + ID
            plt.savefig(saveName)
        plt.show()

    def plotAllPressureSegAndAvg(self, ID, T1 = False, CP = False, T3 = False, savePlot = False):
        if T1:
            pressSegs = [self.normSeg0T1, self.normSeg1T1, self.normSeg2T1, self.normSeg3T1, self.normSeg4T1, self.normSeg5T1,
                     self.normSeg6T1, self.normSeg7T1, self.normSeg8T1, self.normSeg9T1]
            pressAvgs = [self.avgSeg0T1, self.avgSeg1T1, self.avgSeg2T1, self.avgSeg3T1, self.avgSeg4T1, self.avgSeg5T1,
                     self.avgSeg6T1, self.avgSeg7T1, self.avgSeg8T1, self.avgSeg9T1]
        elif CP:
            pressSegs = [self.normSeg0CP, self.normSeg1CP, self.normSeg2CP, self.normSeg3CP, self.normSeg4CP, self.normSeg5CP,
                     self.normSeg6CP, self.normSeg7CP, self.normSeg8CP, self.normSeg9CP]
            pressAvgs = [self.avgSeg0CP, self.avgSeg1CP, self.avgSeg2CP, self.avgSeg3CP, self.avgSeg4CP, self.avgSeg5CP,
                     self.avgSeg6CP, self.avgSeg7CP, self.avgSeg8CP, self.avgSeg9CP]
        elif T3:
            pressSegs = [self.normSeg0T3, self.normSeg1T3, self.normSeg2T3, self.normSeg3T3, self.normSeg4T3, self.normSeg5T3,
                     self.normSeg6T3, self.normSeg7T3, self.normSeg8T3, self.normSeg9T3]
            pressAvgs = [self.avgSeg0T3, self.avgSeg1T3, self.avgSeg2T3, self.avgSeg3T3, self.avgSeg4T3, self.avgSeg5T3,
                     self.avgSeg6T3, self.avgSeg7T3, self.avgSeg8T3, self.avgSeg9T3]
        posList = ["right 1", "right 2", "right 5", "right 3", "left 5", "right 4", "left 3", "left 4", "left 2", "left 1"]
        #self.Pressure0 = dataArduino.Pressure0.to_numpy() #Right foot furthest back
        #self.Pressure1 = dataArduino.Pressure1.to_numpy() #Right foot second furthest back
        #self.Pressure2 = dataArduino.Pressure2.to_numpy() #Right foot forward to the right
        #self.Pressure3 = dataArduino.Pressure3.to_numpy() #Right foot middle
        #self.Pressure4 = dataArduino.Pressure4.to_numpy() #Left foot forward right
        #self.Pressure5 = dataArduino.Pressure5.to_numpy() #Right foot forward left
        #self.Pressure6 = dataArduino.Pressure6.to_numpy() #Left foot middle
        #self.Pressure7 = dataArduino.Pressure7.to_numpy() #Left foot forward left
        #self.Pressure8 = dataArduino.Pressure8.to_numpy() #Left foot second furthest back
        #self.Pressure9 = dataArduino.Pressure9.to_numpy() #Left foot furthest back
        #Testing something here
        for i in range(len(pressSegs)):
            fig, ax1 = plt.subplots(figsize=(32, 16), dpi=150)
            ax1.plot(np.linspace(start=0, stop=((len(pressAvgs[i])) * self.fs_Arduino), num=(len(pressAvgs[i]))),
                 pressAvgs[i][:], "r", linewidth=4)
        # plt.plot(
        #    np.linspace(start=0, stop=((len(avgData)) * self.fs_Arduino), num=(len(avgData))),
        #    avgData[:], "r", linewidth=4)
            axisList = []
            ax2 = ax1.twinx()
            for j in range(len(pressSegs[i])):
                #axisList.append(ax1.twinx())
                #axisList[j].plot(np.linspace(start=0, stop=(len(pressSegs[i][j])) * self.fs_Arduino, num=(len(pressSegs[i][j]))),
                #                pressSegs[i][j], "b--")
                #fig.axes[j].get_yaxis().set_visible(False)
                ax2.plot(np.linspace(start=0, stop=(len(pressSegs[i][j])) * self.fs_Arduino, num=(len(pressSegs[i][j]))),
                         pressSegs[i][j], "b--")
            # plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
            #                     num=(len(normData[i]))), normData[i], "b--")
            plt.grid(axis='x')
            plt.title("Pressure segmented and averaged " + "position " + posList[i] + " - " + ID)
            plt.xticks(np.arange(start=0, stop=((len(pressAvgs[i])) * self.fs_Arduino), step=0.05))
            if savePlot:
                saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots2\\SegPressV2_Press" + str(i) + ID
                plt.savefig(saveName)
            #plt.show()

    def segmentScale(self):
        #alright so i have the peaks for the normal PPG but not the PPG scale. I can probably take their position use that to find the scale segments then
        #shorten the scale segments. Lets actually try that
        peaks = self.T1Peaks
        scaleSegmentList = []
        for i in range(len(peaks) - 1):
            # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
            segment = self.Scale[peaks[i] - int(0.5 / self.fs_Arduino): peaks[i + 1] + int(
                0.5 / self.fs_Arduino)]  # This will probably make wrongly segmented segments worse.
            scaleSegmentList.append(segment)
        scaleSegmentList, popList = self.sanityCheckSeg(scaleSegmentList)
        for i in range(len(scaleSegmentList)):
            scaleSegmentList[i] = scaleSegmentList[i][1::2]
#        scaleSegmentList = scaleSegmentList[1::2]
        self.scaleSegmentListT1 = scaleSegmentList
        self.popListScaleT1 = popList
        normScale=[]
        for i in self.scaleSegmentListT1:
            normScale.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.scaleSegmentListT1 = normScale
        self.avgScaleSegT1 = dpf.averageSegments(segments=self.scaleSegmentListT1)


        peaks = self.CPPeaks
        scaleSegmentList = []
        for i in range(len(peaks) - 1):
            # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
            segment = self.Scale[peaks[i] - int(0.5 / self.fs_Arduino): peaks[i + 1] + int(
                0.5 / self.fs_Arduino)]  # This will probably make wrongly segmented segments worse.
            scaleSegmentList.append(segment)
        scaleSegmentList, popList = self.sanityCheckSeg(scaleSegmentList)
        for i in range(len(scaleSegmentList)):
            scaleSegmentList[i] = scaleSegmentList[i][1::2]
        self.scaleSegmentListCP = scaleSegmentList
        self.popListScaleCP = popList
        normScale=[]
        for i in self.scaleSegmentListCP:
            normScale.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.scaleSegmentListCP = normScale
        self.avgScaleSegCP = dpf.averageSegments(segments=self.scaleSegmentListCP)


        peaks = self.T3Peaks
        scaleSegmentList = []
        for i in range(len(peaks) - 1):
            # Takes a subset from data from peak1 to peak2 and pad about 0.15 seconds on each side
            segment = self.Scale[peaks[i] - int(0.5 / self.fs_Arduino): peaks[i + 1] + int(
                0.5 / self.fs_Arduino)]  # This will probably make wrongly segmented segments worse.
            scaleSegmentList.append(segment)
        scaleSegmentList, popList = self.sanityCheckSeg(scaleSegmentList)
        for i in range(len(scaleSegmentList)):
            scaleSegmentList[i] = scaleSegmentList[i][1::2]
#        scaleSegmentList = scaleSegmentList[1::2]
        self.scaleSegmentListT3 = scaleSegmentList
        self.popListScaleT3 = popList
        normScale=[]
        for i in self.scaleSegmentListT3:
            normScale.append(dpf.normZScore(i.reshape(-1, 1)).reshape(1, -1).flatten())
        self.scaleSegmentListT3 = normScale
        self.avgScaleSegT3 = dpf.averageSegments(segments=self.scaleSegmentListT3)


    def plotSegScaleT1(self):
        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(np.linspace(start=0, stop=((len(self.avgScaleSegT1)) * self.fs_Scale), num=(len(self.avgScaleSegT1))),
                 self.avgScaleSegT1[:], "r", linewidth=4)
        for i in range(len(self.scaleSegmentListT1)):
            plt.plot(np.linspace(start=0, stop=(len(self.scaleSegmentListT1[i])) * self.fs_Scale,
                                 num=(len(self.scaleSegmentListT1[i]))), self.scaleSegmentListT1[i], "b--")
        plt.grid(axis='x')
        plt.title("Scale segmented and averaged")
        plt.xticks(np.arange(start=0, stop=((len(self.scaleSegmentListT1[1])) * self.fs_Scale), step=0.1))
        # plt.savefig("C:\\Users\\simon\\Documents\\Master\\Bilder\\filtered_segmented_with_PPG_Scale_back_from_shoes_2_0_with_ppg__scale_03_04_2022_test1.png")
        plt.show()

    def plotSegScaleCP(self):
        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(np.linspace(start=0, stop=((len(self.avgScaleSegCP)) * self.fs_Scale), num=(len(self.avgScaleSegCP))),
                 self.avgScaleSegCP[:], "r", linewidth=4)
        for i in range(len(self.scaleSegmentListCP)):
            plt.plot(np.linspace(start=0, stop=(len(self.scaleSegmentListCP[i])) * self.fs_Scale,
                                 num=(len(self.scaleSegmentListCP[i]))), self.scaleSegmentListCP[i], "b--")
        plt.grid(axis='x')
        plt.title("Scale segmented and averaged")
        plt.xticks(np.arange(start=0, stop=((len(self.scaleSegmentListCP[1])) * self.fs_Scale), step=0.1))
        # plt.savefig("C:\\Users\\simon\\Documents\\Master\\Bilder\\filtered_segmented_with_PPG_Scale_back_from_shoes_2_0_with_ppg__scale_03_04_2022_test1.png")
        plt.show()

    def plotSegScaleT3(self):
        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(np.linspace(start=0, stop=((len(self.avgScaleSegT3)) * self.fs_Scale), num=(len(self.avgScaleSegT3))),
                 self.avgScaleSegT3[:], "r", linewidth=4)
        for i in range(len(self.scaleSegmentListT3)):
            plt.plot(np.linspace(start=0, stop=(len(self.scaleSegmentListT3[i])) * self.fs_Scale,
                                 num=(len(self.scaleSegmentListT3[i]))), self.scaleSegmentListT3[i], "b--")
        plt.grid(axis='x')
        plt.title("Scale segmented and averaged")
        plt.xticks(np.arange(start=0, stop=((len(self.scaleSegmentListT3[1])) * self.fs_Scale), step=0.1))
        # plt.savefig("C:\\Users\\simon\\Documents\\Master\\Bilder\\filtered_segmented_with_PPG_Scale_back_from_shoes_2_0_with_ppg__scale_03_04_2022_test1.png")
        plt.show()

    def plotPPGAvgVsScaleAvgT1(self):
        #x1 = np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg)))

        fig, ax1 = plt.subplots(figsize=(16, 8), dpi=250)
        l1, = ax1.plot(np.linspace(start=0, stop=((len(self.avgScaleSegT1)) * self.fs_Scale), num=(len(self.avgScaleSegT1))),
                 self.avgScaleSegT1[:], "r", linewidth=2)
        ax2 = ax1.twinx()

        l2, = ax2.plot(np.linspace(start=0, stop=(len(self.avgSeg0T1)) * self.fs_Arduino, num=(len(self.avgSeg0T1))),
                 self.avgSeg0T1, "b", linewidth=2)
        #plt.axvline(x=x1[ppgPeak[0][0]])
        #plt.axvline(x=x1[bcgPeak[0][0]])
        #print("PPG peak:", x1[ppgPeak[0][0]], " and bcg peak: ", x1[bcgPeak[0][0]])
        #fig.axes[1].get_yaxis().set_visible(False)
        #fig.axes[0].get_yaxis().set_visible(False)
        # plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
        #                     num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.legend([l1, l2], ["Pressure averaged", "PPG average"], loc="upper left",
                   fontsize=14)
        #ax1.legend(loc='upper left', fontsize=10)
        ax1.set_xlabel("Time [seconds]", fontsize=16)
        ax1.set_ylabel("Scale normalized", fontsize=16)
        ax2.set_ylabel("Pressure normalized", fontsize=16)
        plt.title("Scale segments averaged vs pressure average - T1")
        plt.tight_layout()
        plt.xticks(np.arange(start=0, stop=((len(self.avgScaleSegT1)) * self.fs_Scale), step=0.1))
        plt.show()

    def plotPPGAvgVsScaleAvgCP(self):
        #x1 = np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg)))

        fig, ax1 = plt.subplots(figsize=(16, 8), dpi=250)
        l1, = ax1.plot(np.linspace(start=0, stop=((len(self.avgScaleSegCP)) * self.fs_Scale), num=(len(self.avgScaleSegCP))),
                 self.avgScaleSegCP[:], "r", linewidth=2)
        ax2 = ax1.twinx()

        l2, = ax2.plot(np.linspace(start=0, stop=(len(self.avgSeg0CP)) * self.fs_Arduino, num=(len(self.avgSeg0CP))),
                 self.avgSeg0CP, "b", linewidth=2)
        #plt.axvline(x=x1[ppgPeak[0][0]])
        #plt.axvline(x=x1[bcgPeak[0][0]])
        #print("PPG peak:", x1[ppgPeak[0][0]], " and bcg peak: ", x1[bcgPeak[0][0]])
        #fig.axes[1].get_yaxis().set_visible(False)
        #fig.axes[0].get_yaxis().set_visible(False)
        # plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
        #                     num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.legend([l1, l2], ["Pressure averaged", "PPG average"], loc="upper left",
                   fontsize=14)
        #ax1.legend(loc='upper left', fontsize=10)
        ax1.set_xlabel("Time [seconds]", fontsize=16)
        ax1.set_ylabel("Scale normalized", fontsize=16)
        ax2.set_ylabel("Pressure normalized", fontsize=16)
        plt.title("Scale segments averaged vs pressure average - T1")
        plt.tight_layout()
        plt.title("Scale segments averaged vs pressure segments averaged - T2")
        plt.xticks(np.arange(start=0, stop=((len(self.avgScaleSegCP)) * self.fs_Scale), step=0.05))
        plt.show()

    def plotPPGAvgVsScaleAvgT3(self):
        #x1 = np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg)))

        fig, ax1 = plt.subplots(figsize=(16, 8), dpi=250)
        l1, = ax1.plot(np.linspace(start=0, stop=((len(self.avgScaleSegT3)) * self.fs_Scale), num=(len(self.avgScaleSegT3))),
                 self.avgScaleSegT3[:], "r", linewidth=2)
        ax2 = ax1.twinx()

        l2, = ax2.plot(np.linspace(start=0, stop=(len(self.avgSeg0T3)) * self.fs_Arduino, num=(len(self.avgSeg0T3))),
                 self.avgSeg0T3, "b", linewidth=2)
        #plt.axvline(x=x1[ppgPeak[0][0]])
        #plt.axvline(x=x1[bcgPeak[0][0]])
        #print("PPG peak:", x1[ppgPeak[0][0]], " and bcg peak: ", x1[bcgPeak[0][0]])
        #fig.axes[1].get_yaxis().set_visible(False)
        #fig.axes[0].get_yaxis().set_visible(False)
        # plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
        #                     num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.legend([l1, l2], ["Pressure averaged", "PPG average"], loc="upper left",
                   fontsize=14)
        #ax1.legend(loc='upper left', fontsize=10)
        ax1.set_xlabel("Time [seconds]", fontsize=16)
        ax1.set_ylabel("Scale normalized", fontsize=16)
        ax2.set_ylabel("Pressure normalized", fontsize=16)
        plt.title("Scale segments averaged vs pressure average - T1")
        plt.tight_layout()
        plt.title("Scale segments averaged vs pressure segments averaged - T3")
        plt.xticks(np.arange(start=0, stop=((len(self.avgScaleSegT3)) * self.fs_Scale), step=0.05))
        plt.show()


    def plotSegPPG(self, T1 = False, CP = False, T3 = False, savePlot = False, ID = ""):
        #TODO:
        if T1:
            avgData = self.avgSegPPGT1
            normData = self.normSegPPGT1
        elif CP:
            avgData = self.avgSegPPGCP
            normData = self.normSegPPGCP
        elif T3:
            avgData = self.avgSegPPGT3
            normData = self.normSegPPGT3


        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(
            np.linspace(start=0, stop=((len(avgData)) * self.fs_Arduino), num=(len(avgData))),
            avgData[:], "r", linewidth=4)
        for i in range(len(normData)):
            plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
                                 num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.title("PPG segmented and averaged")
        plt.xticks(np.arange(start=0, stop=((len(avgData)) * self.fs_Arduino), step=0.05))
        if savePlot:
            if T1:
                timeStr = "T1"
            elif CP:
                timeStr = "CP"
            elif T3:
                timeStr = "T3"
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\SegPPG_" + ID + "_" + timeStr
            plt.savefig(saveName)
        # plt.savefig("C:\\Users\\simon\\Documents\\Master\\Bilder\\filtered_segmented_with_PPG_right_foot_second_furthest_back_interpolated_from_shoes_2_0_with_ppg__scale_03_04_2022_test1.png")
        plt.show()

    def plotPeaksVSPPGT1(self, savePlot = False, ID = ""):
        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(self.timeArduino[self.T1TimeArduino[0]:self.T1TimeArduino[1]],
                            self.PPGFilt[self.T1TimeArduino[0]:self.T1TimeArduino[1]])
        for i in self.T1Peaks:
            plt.axvline(x=self.timeArduino[i])
        #Poplist contains a list of indices of wrong segments. Each segment has atleast one peak wrongly identified next to it
        #The indice of a wrong segment corresponds to the indice of the peak in front of the segment.
        #I dont know which peak is wrong....
        lastIndice = 0
        for j in range(len(self.popListT1)):
            try:
                if abs(self.popListT1[j] - self.popListT1[j + 1]) == 1:
                    plt.axvline(x=self.timeArduino[self.T1Peaks[self.popListT1[j+1]]], color="r")
                else:
                    plt.axvline(x=self.timeArduino[self.T1Peaks[self.popListT1[j]]], color="r")
            except IndexError:
                plt.axvline(x=self.timeArduino[self.T1Peaks[self.popListT1[j]]], color="r")
        plt.title("PPG and identified PPG peaks")
        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\SegPPG" + "_T1_" + ID
            plt.savefig(saveName)
        plt.show()

    def plotPeaksVSPPGCP(self, savePlot = False, ID = ""):
        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(self.timeArduino[self.CPTimeArduino[0]:self.CPTimeArduino[1]],
                 self.PPGFilt[self.CPTimeArduino[0]:self.CPTimeArduino[1]])
        for i in self.CPPeaks:
            plt.axvline(x=self.timeArduino[i])

        for j in range(len(self.popListCP)):
            try:
                if abs(self.popListCP[j] - self.popListCP[j + 1]) == 1:
                    plt.axvline(x=self.timeArduino[self.CPPeaks[self.popListCP[j+1]]], color="r")
                else:
                    plt.axvline(x=self.timeArduino[self.CPPeaks[self.popListCP[j]]], color="r")
            except IndexError:
                plt.axvline(x=self.timeArduino[self.CPPeaks[self.popListCP[j]]], color="r")
        plt.title("PPG and identified PPG peaks")
        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\SegPPG" + "_CP_" + ID
            plt.savefig(saveName)
        plt.show()

    def plotPeaksVSPPGT3(self, savePlot = False, ID = ""):
        plt.figure(figsize=(32, 16), dpi=150)
        plt.plot(self.timeArduino[self.T3TimeArduino[0]:self.T3TimeArduino[1]],
                            self.PPGFilt[self.T3TimeArduino[0]:self.T3TimeArduino[1]])
        for i in self.T3Peaks:
            plt.axvline(x=self.timeArduino[i])

        for j in range(len(self.popListT3)):
            try:
                if abs(self.popListT3[j] - self.popListT3[j + 1]) == 1:
                    plt.axvline(x=self.timeArduino[self.T3Peaks[self.popListT3[j+1]]], color="r")
                else:
                    plt.axvline(x=self.timeArduino[self.T3Peaks[self.popListT3[j]]], color="r")
            except IndexError:
                plt.axvline(x=self.timeArduino[self.T3Peaks[self.popListT3[j]]], color="r")
        plt.title("PPG and identified PPG peaks")
        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\SegPPG" + "_CP_" + ID
            plt.savefig(saveName)
        plt.show()

    def plotRightFootT1(self, savePlot = False, ID = ""):
        fig, (ax1, ax2, ax3, ax4, ax5) = plt.subplots(5, figsize=(16,16), dpi=150)
        fig.suptitle('Right foot sensors - T1', fontsize=24)

        ax1.plot(np.linspace(start=0, stop=((len(self.avgSeg0T1)) * self.fs_Arduino), num=(len(self.avgSeg0T1))), self.avgSeg0T1)
        ax1.set_title("Furthest back", fontsize=16)
        ax2.plot(np.linspace(start=0, stop=((len(self.avgSeg1T1)) * self.fs_Arduino), num=(len(self.avgSeg1T1))), self.avgSeg1T1)
        ax2.set_title("Second furthest back", fontsize=16)
        ax3.plot(np.linspace(start=0, stop=((len(self.avgSeg3T1)) * self.fs_Arduino), num=(len(self.avgSeg3T1))), self.avgSeg3T1)
        ax3.set_title("Middle", fontsize=16)
        ax4.plot(np.linspace(start=0, stop=((len(self.avgSeg5T1)) * self.fs_Arduino), num=(len(self.avgSeg5T1))), self.avgSeg5T1)
        ax4.set_title("Left forward", fontsize=16)
        ax5.plot(np.linspace(start=0, stop=((len(self.avgSeg2T1)) * self.fs_Arduino), num=(len(self.avgSeg2T1))), self.avgSeg2T1)
        ax5.set_title("Right forward", fontsize=16)
        fig.tight_layout()

        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\RightFootT1_" + ID
            plt.savefig(saveName)

        plt.show()

    def plotLeftFootT1(self, savePlot=False, ID =""):
        fig, (ax1, ax2, ax3, ax4, ax5) = plt.subplots(5, figsize=(16,16), dpi=150)
        fig.suptitle('Left foot sensors - T1', fontsize=24)

        ax1.plot(np.linspace(start=0, stop=((len(self.avgSeg9T1)) * self.fs_Arduino), num=(len(self.avgSeg9T1))), self.avgSeg9T1)
        ax1.set_title("Furthest back", fontsize=16)
        ax2.plot(np.linspace(start=0, stop=((len(self.avgSeg8T1)) * self.fs_Arduino), num=(len(self.avgSeg8T1))), self.avgSeg8T1)
        ax2.set_title("Second furthest back", fontsize=16)
        ax3.plot(np.linspace(start=0, stop=((len(self.avgSeg6T1)) * self.fs_Arduino), num=(len(self.avgSeg6T1))), self.avgSeg6T1)
        ax3.set_title("Middle", fontsize=16)
        ax4.plot(np.linspace(start=0, stop=((len(self.avgSeg7T1)) * self.fs_Arduino), num=(len(self.avgSeg7T1))), self.avgSeg7T1)
        ax4.set_title("Left forward", fontsize=16)
        ax5.plot(np.linspace(start=0, stop=((len(self.avgSeg4T1)) * self.fs_Arduino), num=(len(self.avgSeg4T1))), self.avgSeg4T1)
        ax5.set_title("Right forward", fontsize=16)
        fig.tight_layout()

        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\LeftFootT1_" + ID
            plt.savefig(saveName)

        plt.show()

    def plotRightFootCP(self, savePlot = False, ID=""):
        fig, (ax1, ax2, ax3, ax4, ax5) = plt.subplots(5, figsize=(16,16), dpi=150)
        fig.suptitle('Right foot sensors - Cold pressor', fontsize=24)

        ax1.plot(np.linspace(start=0, stop=((len(self.avgSeg0CP)) * self.fs_Arduino), num=(len(self.avgSeg0CP))), self.avgSeg0CP)
        ax1.set_title("Furthest back", fontsize=16)
        ax2.plot(np.linspace(start=0, stop=((len(self.avgSeg1CP)) * self.fs_Arduino), num=(len(self.avgSeg1CP))), self.avgSeg1CP)
        ax2.set_title("Second furthest back", fontsize=16)
        ax3.plot(np.linspace(start=0, stop=((len(self.avgSeg3CP)) * self.fs_Arduino), num=(len(self.avgSeg3CP))), self.avgSeg3CP)
        ax3.set_title("Middle", fontsize=16)
        ax4.plot(np.linspace(start=0, stop=((len(self.avgSeg5CP)) * self.fs_Arduino), num=(len(self.avgSeg5CP))), self.avgSeg5CP)
        ax4.set_title("Left forward", fontsize=16)
        ax5.plot(np.linspace(start=0, stop=((len(self.avgSeg2CP)) * self.fs_Arduino), num=(len(self.avgSeg2CP))), self.avgSeg2CP)
        ax5.set_title("Right forward", fontsize=16)
        fig.tight_layout()

        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\RightFootCP_" + ID
            plt.savefig(saveName)

        plt.show()

    def plotLeftFootCP(self, savePlot=False, ID = ""):
        fig, (ax1, ax2, ax3, ax4, ax5) = plt.subplots(5, figsize=(16,16), dpi=150)
        fig.suptitle('Left foot sensors - Cold pressor', fontsize=24)

        ax1.plot(np.linspace(start=0, stop=((len(self.avgSeg9CP)) * self.fs_Arduino), num=(len(self.avgSeg9CP))), self.avgSeg9CP)
        ax1.set_title("Furthest back", fontsize=16)
        ax2.plot(np.linspace(start=0, stop=((len(self.avgSeg8CP)) * self.fs_Arduino), num=(len(self.avgSeg8CP))), self.avgSeg8CP)
        ax2.set_title("Second furthest back", fontsize=16)
        ax3.plot(np.linspace(start=0, stop=((len(self.avgSeg6CP)) * self.fs_Arduino), num=(len(self.avgSeg6CP))), self.avgSeg6CP)
        ax3.set_title("Middle", fontsize=16)
        ax4.plot(np.linspace(start=0, stop=((len(self.avgSeg7CP)) * self.fs_Arduino), num=(len(self.avgSeg7CP))), self.avgSeg7CP)
        ax4.set_title("Left forward", fontsize=16)
        ax5.plot(np.linspace(start=0, stop=((len(self.avgSeg4CP)) * self.fs_Arduino), num=(len(self.avgSeg4CP))), self.avgSeg4CP)
        ax5.set_title("Right forward", fontsize=16)
        fig.tight_layout()

        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\LeftFootCP_" + ID
            plt.savefig(saveName)

        plt.show()

    def plotRightFootT3(self, savePlot=False, ID=""):
        fig, (ax1, ax2, ax3, ax4, ax5) = plt.subplots(5, figsize=(16,16), dpi=150)
        fig.suptitle('Right foot sensors - T3', fontsize=24)

        ax1.plot(np.linspace(start=0, stop=((len(self.avgSeg0T3)) * self.fs_Arduino), num=(len(self.avgSeg0T3))), self.avgSeg0T3)
        ax1.set_title("Furthest back", fontsize=16)
        ax2.plot(np.linspace(start=0, stop=((len(self.avgSeg1T3)) * self.fs_Arduino), num=(len(self.avgSeg1T3))), self.avgSeg1T3)
        ax2.set_title("Second furthest back", fontsize=16)
        ax3.plot(np.linspace(start=0, stop=((len(self.avgSeg3T3)) * self.fs_Arduino), num=(len(self.avgSeg3T3))), self.avgSeg3T3)
        ax3.set_title("Middle", fontsize=16)
        ax4.plot(np.linspace(start=0, stop=((len(self.avgSeg5T3)) * self.fs_Arduino), num=(len(self.avgSeg5T3))), self.avgSeg5T3)
        ax4.set_title("Left forward", fontsize=16)
        ax5.plot(np.linspace(start=0, stop=((len(self.avgSeg2T3)) * self.fs_Arduino), num=(len(self.avgSeg2T3))), self.avgSeg2T3)
        ax5.set_title("Right forward", fontsize=16)
        fig.tight_layout()

        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\RightFootT3_" + ID
            plt.savefig(saveName)

        plt.show()

    def plotLeftFootT3(self, savePlot=False, ID=""):
        fig, (ax1, ax2, ax3, ax4, ax5) = plt.subplots(5, figsize=(16,16), dpi=150)
        fig.suptitle('Left foot sensors', fontsize=24)

        ax1.plot(np.linspace(start=0, stop=((len(self.avgSeg9T3)) * self.fs_Arduino), num=(len(self.avgSeg9T3))), self.avgSeg9T3)
        ax1.set_title("Furthest back", fontsize=16)
        ax2.plot(np.linspace(start=0, stop=((len(self.avgSeg8T3)) * self.fs_Arduino), num=(len(self.avgSeg8T3))), self.avgSeg8T3)
        ax2.set_title("Second furthest back", fontsize=16)
        ax3.plot(np.linspace(start=0, stop=((len(self.avgSeg6T3)) * self.fs_Arduino), num=(len(self.avgSeg6T3))), self.avgSeg6T3)
        ax3.set_title("Middle", fontsize=16)
        ax4.plot(np.linspace(start=0, stop=((len(self.avgSeg7T3)) * self.fs_Arduino), num=(len(self.avgSeg7T3))), self.avgSeg7T3)
        ax4.set_title("Left forward", fontsize=16)
        ax5.plot(np.linspace(start=0, stop=((len(self.avgSeg4T3)) * self.fs_Arduino), num=(len(self.avgSeg4T3))), self.avgSeg4T3)
        ax5.set_title("Right forward", fontsize=16)
        fig.tight_layout()

        if savePlot:
            saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots\\LeftFootT3_" + ID
            plt.savefig(saveName)

        plt.show()

    def plotLeftAndRightFootT1(self): # Not finished.
        fig, axs = plt.sublpots(5, 2, figsize=(16, 32), dpi = 150)
        fig.suptitle('Left and right foot pressure', fontsize=24)
        #Right foot sensors
        axs[0, 0].plot(np.linspace(start=0, stop=((len(self.avgSeg0T1)) * self.fs_Arduino), num=(len(self.avgSeg0T1))), self.avgSeg0T1)
        axs[0, 0].set_title("Furthest back", fontsize=16)
        axs[1, 0].plot(np.linspace(start=0, stop=((len(self.avgSeg1T3)) * self.fs_Arduino), num=(len(self.avgSeg1T3))),
                 self.avgSeg1T3)
        axs[1, 0].set_title("Second furthest back", fontsize=16)
        axs[2, 0].plot(np.linspace(start=0, stop=((len(self.avgSeg3T3)) * self.fs_Arduino), num=(len(self.avgSeg3T3))),
                 self.avgSeg3T3)
        axs[2, 0].set_title("Middle", fontsize=16)
        axs[3, 0].plot(np.linspace(start=0, stop=((len(self.avgSeg5T3)) * self.fs_Arduino), num=(len(self.avgSeg5T3))),
                 self.avgSeg5T3)
        axs[3, 0].set_title("Left forward", fontsize=16)
        axs[4, 0].plot(np.linspace(start=0, stop=((len(self.avgSeg2T3)) * self.fs_Arduino), num=(len(self.avgSeg2T3))),
                 self.avgSeg2T3)
        axs[4, 0].set_title("Right forward", fontsize=16)
        fig.tight_layout()


    def plotPPGavgVsPressavgT1(self, pressSelect, savePlot = False): #Not finished
        if pressSelect == 0:
            pressAvg = self.avgSeg0T1
        if pressSelect == 1:
            pressAvg = self.avgSeg1T1
        if pressSelect == 2:
            pressAvg = self.avgSeg2T1
        if pressSelect == 3:
            pressAvg = self.avgSeg3T1
        if pressSelect == 4:
            pressAvg = self.avgSeg4T1
        if pressSelect == 5:
            pressAvg = self.avgSeg5T1
        if pressSelect == 6:
            pressAvg = self.avgSeg6T1
        if pressSelect == 7:
            pressAvg = self.avgSeg7T1
        if pressSelect == 8:
            pressAvg = self.avgSeg8T1
        if pressSelect == 9:
            pressAvg = self.avgSeg9T1
        ppgPeak = scipy.signal.find_peaks(self.avgSegPPGT1, height=0.5)#, distance=1/self.fs_Arduino) #Find the peak within 1 second
        bcgPeak = scipy.signal.find_peaks(pressAvg, height=0.6)
        x1 = np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg)))


        fig, ax1 = plt.subplots(figsize=(16, 8), dpi = 250)
        l1, = ax1.plot(np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg))),
                 pressAvg[:], "r", linewidth=2)
        ax2 = ax1.twinx()

        l2, = ax2.plot(np.linspace(start=0, stop=(len(self.avgSegPPGT1)) * self.fs_Arduino, num=(len(self.avgSegPPGT1))),
                         self.avgSegPPGT1, "b", linewidth=2)
        plt.axvline(x=x1[ppgPeak[0][0]])
        plt.axvline(x=x1[bcgPeak[0][1]], color="r")
        fig.axes[1].get_yaxis().set_visible(False)
        fig.axes[0].get_yaxis().set_visible(False)
        ax1.set_ylabel("Pressure normalized", fontsize=18)
        ax2.set_ylabel("PPG normalized", fontsize=18)
        ax1.set_xlabel("Time [seconds]", fontsize=18)
        plt.legend([l1, l2], ["Pressure segments averaged", "PPG segments averaged"], loc="upper right",
                   fontsize=14)
        print("PPG peak:", x1[ppgPeak[0][1]], " and bcg peak: ", x1[bcgPeak[0][1]])
        #fig.axes[1].get_yaxis().set_visible(False)
        #fig.axes[0].get_yaxis().set_visible(False)
            #plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
            #                     num=(len(normData[i]))), normData[i], "b--")
        #plt.legend([l1, l2], ["Pressure averaged", "PPG average"], loc="upper left",
        #           fontsize=10)
        #ax1.legend(loc='upper left', fontsize=10)
        #ax1.set_xlabel("Time [seconds]", fontsize=16)
        plt.grid(axis='x')
        plt.title("Pressure segments averaged vs PPG segments averaged - T1")
        plt.xticks(np.arange(start=0, stop=((len(self.avgSeg0T1)) * self.fs_Arduino), step=0.05))
        plt.show()

    def plotPPGavgVsPressavgCP(self, pressSelect, savePlot = False): #Not finished
        if pressSelect == 0:
            pressAvg = self.avgSeg0CP
        if pressSelect == 1:
            pressAvg = self.avgSeg1CP
        if pressSelect == 2:
            pressAvg = self.avgSeg2CP
        if pressSelect == 3:
            pressAvg = self.avgSeg3CP
        if pressSelect == 4:
            pressAvg = self.avgSeg4CP
        if pressSelect == 5:
            pressAvg = self.avgSeg5CP
        if pressSelect == 6:
            pressAvg = self.avgSeg6CP
        if pressSelect == 7:
            pressAvg = self.avgSeg7CP
        if pressSelect == 8:
            pressAvg = self.avgSeg8CP
        if pressSelect == 9:
            pressAvg = self.avgSeg9CP

        ppgPeak = scipy.signal.find_peaks(self.avgSegPPGCP, height=0.5)#, distance=1/self.fs_Arduino) #Find the peak within 1 second
        bcgPeak = scipy.signal.find_peaks(pressAvg, height=0.6)
        x1 = np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg)))


        fig, ax1 = plt.subplots(figsize=(16, 8), dpi = 250)
        l1, = ax1.plot(np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg))),
                 pressAvg[:], "r", linewidth=2)
        ax2 = ax1.twinx()

        l2, = ax2.plot(np.linspace(start=0, stop=(len(self.avgSegPPGCP)) * self.fs_Arduino, num=(len(self.avgSegPPGCP))),
                         self.avgSegPPGCP, "b", linewidth=2)
        fig.axes[1].get_yaxis().set_visible(False)
        fig.axes[0].get_yaxis().set_visible(False)


        ax1.set_xlabel("Time [seconds]", fontsize=18)
        plt.legend([l1, l2], ["Pressure segments averaged", "PPG segments averaged"], loc="upper right",
                   fontsize=14)
        plt.axvline(x=x1[ppgPeak[0][0]])
        plt.axvline(x=x1[bcgPeak[0][1]], color = "r")
        ax1.set_ylabel("Pressure normalized", fontsize=18)
        ax2.set_ylabel("PPG normalized", fontsize=18)
        print("PPG peak:", x1[ppgPeak[0][0]], " and bcg peak: ", x1[bcgPeak[0][1]])

        #fig.axes[1].get_yaxis().set_visible(False)
            #plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
            #                     num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.title("Pressure segments averaged vs PPG segments averaged - T2")
        plt.xticks(np.arange(start=0, stop=((len(self.avgSeg0CP)) * self.fs_Arduino), step=0.05))
        plt.show()

    def plotPPGavgVsPressavgT3(self, pressSelect, savePlot = False): #Not finished
        if pressSelect == 0:
            pressAvg = self.avgSeg0T3
        if pressSelect == 1:
            pressAvg = self.avgSeg1T3
        if pressSelect == 2:
            pressAvg = self.avgSeg2T3
        if pressSelect == 3:
            pressAvg = self.avgSeg3T3
        if pressSelect == 4:
            pressAvg = self.avgSeg4T3
        if pressSelect == 5:
            pressAvg = self.avgSeg5T3
        if pressSelect == 6:
            pressAvg = self.avgSeg6T3
        if pressSelect == 7:
            pressAvg = self.avgSeg7T3
        if pressSelect == 8:
            pressAvg = self.avgSeg8T3
        if pressSelect == 9:
            pressAvg = self.avgSeg9T3

        ppgPeak = scipy.signal.find_peaks(self.avgSegPPGT3, height=0.5)#, distance=1/self.fs_Arduino) #Find the peak within 1 second
        bcgPeak = scipy.signal.find_peaks(pressAvg, height=0.6)
        x1 = np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg)))

        fig, ax1 = plt.subplots(figsize=(16, 8), dpi = 250)
        l1, = ax1.plot(np.linspace(start=0, stop=((len(pressAvg)) * self.fs_Arduino), num=(len(pressAvg))),
                 pressAvg[:], "r", linewidth=2)
        ax2 = ax1.twinx()
        l2, = ax2.plot(np.linspace(start=0, stop=(len(self.avgSegPPGT3)) * self.fs_Arduino, num=(len(self.avgSegPPGT3))),
                         self.avgSegPPGT3, "b", linewidth=2)
        fig.axes[1].get_yaxis().set_visible(False)
        fig.axes[0].get_yaxis().set_visible(False)
        plt.axvline(x=x1[ppgPeak[0][0]])
        plt.axvline(x=x1[bcgPeak[0][1]], color = "r")
        ax1.set_ylabel("Pressure normalized", fontsize=18)
        ax2.set_ylabel("PPG normalized", fontsize=18)
        ax1.set_xlabel("Time [seconds]", fontsize=18)
        plt.legend([l1, l2], ["Pressure segments averaged", "PPG segments averaged"], loc="upper right",
                   fontsize=14)
        print("PPG peak:", x1[ppgPeak[0][1]], " and bcg peak: ", x1[bcgPeak[0][1]])
        #fig.axes[1].get_yaxis().set_visible(False)
            #plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
            #                     num=(len(normData[i]))), normData[i], "b--")
        plt.grid(axis='x')
        plt.title("Pressure segments averaged vs PPG segments averaged - T3")
        plt.xticks(np.arange(start=0, stop=((len(self.avgSeg0T3)) * self.fs_Arduino), step=0.05))
        plt.show()

    def plotPressureWithPPG(self, ID, T1 = False, CP = False, T3 = False, savePlot = False):
        if T1:
            pressSegs = [self.normSeg0T1, self.normSeg1T1, self.normSeg2T1, self.normSeg3T1, self.normSeg4T1, self.normSeg5T1,
                     self.normSeg6T1, self.normSeg7T1, self.normSeg8T1, self.normSeg9T1]
            pressAvgs = [self.avgSeg0T1, self.avgSeg1T1, self.avgSeg2T1, self.avgSeg3T1, self.avgSeg4T1, self.avgSeg5T1,
                     self.avgSeg6T1, self.avgSeg7T1, self.avgSeg8T1, self.avgSeg9T1]
            ppgAvg = self.avgSegPPGT1
            timeStr = "T1"
        elif CP:
            pressSegs = [self.normSeg0CP, self.normSeg1CP, self.normSeg2CP, self.normSeg3CP, self.normSeg4CP, self.normSeg5CP,
                     self.normSeg6CP, self.normSeg7CP, self.normSeg8CP, self.normSeg9CP]
            pressAvgs = [self.avgSeg0CP, self.avgSeg1CP, self.avgSeg2CP, self.avgSeg3CP, self.avgSeg4CP, self.avgSeg5CP,
                     self.avgSeg6CP, self.avgSeg7CP, self.avgSeg8CP, self.avgSeg9CP]
            ppgAvg = self.avgSegPPGCP
            timeStr = "T2"
        elif T3:
            pressSegs = [self.normSeg0T3, self.normSeg1T3, self.normSeg2T3, self.normSeg3T3, self.normSeg4T3, self.normSeg5T3,
                     self.normSeg6T3, self.normSeg7T3, self.normSeg8T3, self.normSeg9T3]
            pressAvgs = [self.avgSeg0T3, self.avgSeg1T3, self.avgSeg2T3, self.avgSeg3T3, self.avgSeg4T3, self.avgSeg5T3,
                     self.avgSeg6T3, self.avgSeg7T3, self.avgSeg8T3, self.avgSeg9T3]
            ppgAvg = self.avgSegPPGT3
            timeStr = "T3"
        posList = ["right 1", "right 2", "right 5", "right 3", "left 5", "right 4", "left 3", "left 4", "left 2", "left 1"]
        #self.Pressure0 = dataArduino.Pressure0.to_numpy() #Right foot furthest back
        #self.Pressure1 = dataArduino.Pressure1.to_numpy() #Right foot second furthest back
        #self.Pressure2 = dataArduino.Pressure2.to_numpy() #Right foot forward to the right
        #self.Pressure3 = dataArduino.Pressure3.to_numpy() #Right foot middle
        #self.Pressure4 = dataArduino.Pressure4.to_numpy() #Left foot forward right
        #self.Pressure5 = dataArduino.Pressure5.to_numpy() #Right foot forward left
        #self.Pressure6 = dataArduino.Pressure6.to_numpy() #Left foot middle
        #self.Pressure7 = dataArduino.Pressure7.to_numpy() #Left foot forward left
        #self.Pressure8 = dataArduino.Pressure8.to_numpy() #Left foot second furthest back
        #self.Pressure9 = dataArduino.Pressure9.to_numpy() #Left foot furthest back
        #Testing something here
        for i in range(len(pressSegs)):
            fig, (ax1, ax2) = plt.subplots(2, figsize=(12, 8), dpi=250)

            l1, = ax1.plot(np.linspace(start=0, stop=((len(ppgAvg)) * self.fs_Arduino), num=(len(ppgAvg))),
                 ppgAvg[:], "r", linewidth=4, label = "PPG Average")
            ax1.set_title("PPG average based on segmentation", fontsize=24)

            l2, = ax2.plot(np.linspace(start=0, stop=((len(pressAvgs[i])) * self.fs_Arduino), num=(len(pressAvgs[i]))),
                 pressAvgs[i][:], "r", linewidth=4)

        # plt.plot(
        #    np.linspace(start=0, stop=((len(avgData)) * self.fs_Arduino), num=(len(avgData))),
        #    avgData[:], "r", linewidth=4)
            axisList = []
            #ax3 = ax2.twinx() # If i dont twin i force everything onto the same axes
            for j in range(len(pressSegs[i])):
                #axisList.append(ax1.twinx())
                #axisList[j].plot(np.linspace(start=0, stop=(len(pressSegs[i][j])) * self.fs_Arduino, num=(len(pressSegs[i][j]))),
                #                pressSegs[i][j], "b--")
                #fig.axes[j].get_yaxis().set_visible(False)
                l3, = ax2.plot(np.linspace(start=0, stop=(len(pressSegs[i][j])) * self.fs_Arduino, num=(len(pressSegs[i][j]))),
                         pressSegs[i][j], "b--", linewidth=1)
            # plt.plot(np.linspace(start=0, stop=(len(normData[i])) * self.fs_Arduino,
            #                     num=(len(normData[i]))), normData[i], "b--")
            plt.grid(axis='x')
            ax2.set_title("Pressure segmented and averaged - " + "position " + posList[i], fontsize=24)
            plt.xticks(np.arange(start=0, stop=((len(pressAvgs[i])) * self.fs_Arduino), step=0.1))
            plt.legend([l2, l3], ["Average pressure normalized", "Pressure segments normalized"], loc="upper right", fontsize=14)
            ax1.legend(loc='upper right', fontsize = 14)
            ax1.set_xlabel("Time [seconds]", fontsize = 18)
            ax2.set_xlabel("Time [seconds]", fontsize = 18)
            fig.tight_layout()

            if T1:
                tp = "T1"
            elif CP:
                tp = "CP"
            elif T3:
                tp = "T3"
            if savePlot:
                saveName = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\Plots2\\PressAndPPG_Press" + str(i) + "_" + tp + "_" + ID
                plt.savefig(saveName)

            #plt.show()
#Testing functions:
#timeStampsT1_2170 = ["04:05:2022:14:26:00:0", "04:05:2022:14:26:15:0"]
#timeStampsCP_2170 = ["04:05:2022:14:27:40:0", "04:05:2022:14:27:55:0"]
#timeStampsT3_2170 = ["04:05:2022:14:33:00:0", "04:05:2022:14:33:15:0"]
#dataLabChartPath_2170 = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\2170\\2170_Labchart_Raw_Text.txt"
#dataArduinoPath_2170 = "C:\\Users\\simon\\Documents\\Master\\Forsøk\\2170\\2170_Arduino_Raw_4.csv"
#interestingDataList = ["Time", "HC_Systolic", "Active_Cuff", "Finger_Pressure_HC"]
#nameList = ["Time", "Date", "Finger_Pressure", "Finger_Pressure_HC", "HCU_Pressure", "Systolic", "HC_Systolic",
#            "Mean_Arterial", "HC_Mean_Arterial", "Diastolic", "HC_Diastolic", "HR", "Interbeat_Interval", "Active_Cuff",
#           "Cuff_Countdown", "Autocal_Quality", "Autocal_Countdown", "Comments"]
#nameListArduino = ["timestamp", "Time", "PPG", "Scale", "Pressure0", "Pressure1", "Pressure2", "Pressure3", "Pressure4"
#                  , "Pressure5", "Pressure6", "Pressure7", "Pressure8", "Pressure9"]

#Test2170 = Measurement(timeStampsT1_2170, timeStampsCP_2170, timeStampsT3_2170, dataArduinoPath_2170, dataLabChartPath_2170, nameListArduino, nameList)
#Test2170.loadChartData()
#Test2170.SetTimeIndices()
#Test2170.averageFingerPressure()
#Test2170.plotAvgFingPress()
#Test2170.findPPGPeaks(threshold=500, timeBetween=0.5)
#Test2170.organizePeaks()
#Test2170.filterPressure(butterLevel=12, passBand=[3,10])
#Test2170.segmentPressure(ddPPG=False)
#Test2170.segmentPPG(ddPPG=False)
#Test2170.plotSegPress(pressSelect=1, T1 = True)
#Test2170.plotSegPPG(T1 = True)
#Test2170.plotPeaksVSPPGT1()
#Test2170.plotRightFoot()
#print(Test2170.hz_Arduino)

